# charticulator

Component to render charticulator templates with streamlit data

## Installation instructions 

```sh
pip install charticulator
```

## Usage instructions

```python
import streamlit as st

from charticulator import charticulator

value = charticulator()

st.write(value)
